@@ -126,6 +126,9 @@ execProcess cspec spec cgii req = do
       , new_session = False
       , child_group = Nothing
       , child_user = Nothing
+#endif
+#if __GLASGOW_HASKELL__ >= 802
+      , use_process_jobs = False
 #endif
       }
     (prog, scriptName, pathinfo) =
